-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT FAILURE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1000) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1000.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- AlterCls1020.sql
-- #########################################################
-- #########################################################

/* 
       
   -   
*/
/*    ,  KCSR.DirectionExpence */
-- drop trigger TR_CDECLS_BU_0
DROP TRIGGER TR_COMMDIRECTIONEXPENCECLS_BU
/
-- ALTER TRIGGER TR_KCSR_BI_0
CREATE OR REPLACE TRIGGER TR_KCSR_BI
  BEFORE INSERT
  ON KCSR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KCSR_BI_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KCSR_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_KCSR_BU_0
CREATE OR REPLACE TRIGGER TR_KCSR_BU
  BEFORE UPDATE
  ON KCSR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KCSR_BU_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER TR_KVR_BI_0
CREATE OR REPLACE TRIGGER TR_KVR_BI
  BEFORE INSERT
  ON KVR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KVR_BI_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KVR_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER TR_KVR_BU_0
CREATE OR REPLACE TRIGGER TR_KVR_BU
  BEFORE UPDATE
  ON KVR
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KVR_BU_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_FinTypeDiv_bi_0
CREATE OR REPLACE TRIGGER TR_FINTYPE_BI
  BEFORE INSERT
  ON FINTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FINTYPEDIV_BI_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FINTYPE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
-- ALTER TRIGGER tr_FinTypeDiv_bu_0
CREATE OR REPLACE TRIGGER TR_FINTYPE_BU
  BEFORE UPDATE
  ON FINTYPE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_FINTYPEDIV_BU_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_Fact_bi_0
CREATE OR REPLACE TRIGGER TR_FACT_BI
  BEFORE INSERT
  ON FACT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_FACT_BI_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_FACT_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  :new.CreateDate := SYSDATE;
  :new.UpdateDate := :new.CreateDate;
  :new.CreaterUser := user;
  :new.UpdaterUser := user;

END;
/
-- ALTER TRIGGER tr_Fact_bu_0
CREATE OR REPLACE TRIGGER TR_FACT_BU
  BEFORE UPDATE
  ON FACT
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_1 (TR_FACT_BU_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_DocBase_bi_0
CREATE OR REPLACE TRIGGER TR_DOCBASE_BI
  BEFORE INSERT
  ON DOCBASE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_DOCBASE_BI_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.KVSR is null) then
    :new.KVSR := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DOCBASE_BI_500)
-- - - - - - - - - - - - -

  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
-- ALTER TRIGGER tr_DocBase_bu_0
CREATE OR REPLACE TRIGGER TR_DOCBASE_BU
  BEFORE UPDATE
  ON DOCBASE
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_1 (TR_DOCBASE_BU_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.KVSR is null) then
    :new.KVSR := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
-- ALTER TRIGGER tr_directioncls_bi_0
CREATE OR REPLACE TRIGGER TR_DIRECTIONCLS_BI
  BEFORE INSERT
  ON DIRECTIONCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (tr_directioncls_bi_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_DIRECTIONCLS_BI_500)
-- - - - - - - - - - - - -

-- Created 28.09.2004
  :NEW.CreateDate := SYSDATE;
  :NEW.UpdateDate := :NEW.CreateDate;

END;
/
-- ALTER TRIGGER tr_directioncls_bu_0
CREATE OR REPLACE TRIGGER TR_DIRECTIONCLS_BU
  BEFORE UPDATE
  ON DIRECTIONCLS
  FOR EACH ROW
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_directioncls_bu_0)
-- Version 10.20.00.1
-- - - - - - - - - - - - -

  if (:new.Code is null) then
    RaiseException('ex_WrongClsEmpty');
  END IF;
  if (:new.BudgetRef is null) then 
    :new.BudgetRef := 0;
  END IF;
  if (:new.id is null) then
    select g_shared.nextval into :new.id from dual;
  END IF;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Alter_Agreement_ReviewNote_Ora.sql
-- #########################################################
-- #########################################################


ALTER TRIGGER TR_AGREEMENTS_BU_500 DISABLE
/

COMMIT WORK
/

ALTER TABLE TB_AGREEMENTS MODIFY (ReviewNote VARCHAR2(512))
/

COMMIT WORK
/

CREATE OR REPLACE VIEW Agreements (
ID,
SUMMA, 
AGREEMENTDATE, 
AGREEMENTENDDATE, 
EXECUTER_REF, 
CLIENT_REF, 
FACIALACC_CLS, 
AGREEMENTTYPE, 
ACCEPTED, 
ACCEPTDATE, 
CARDADVANCEPERCENT, 
CARDADVANCE, 
CLOSEDOC, 
CREATERUSER, 
CREATEDATE, 
UPDATEDATE, 
UPDATERUSER, 
BUDGETREF, 
LASTADJUSTMENT, 
LASTACCEPTED, 
FACT, 
REGION, 
CLOSEDATE, 
DELIVERYRULES, 
AGREEMENTSUMMA, 
AGREEMENTFINSUMMA, 
ADJUSTMENTREF, 
REESTRNUMBER, 
PAYMENTDATE, 
AGREEMENTCARDADVANCE, 
FINCARDADVANCE, 
STATEORDERREF, 
REJECTCLS, 
REJECTCAUSE, 
CRYPTOSTATUS, 
SENDERID, 
SENDERRECORDID, 
AGREEMENTBEGINDATE, 
PROTOCOLNUMBER, 
PROTOCOLDATE, 
REVIEWNOTE, 
DOCSTATEREF, 
RVERSION, 
EXPORTDATE, 
FSORGAN, 
FSBUDGETNAME, 
FSOFFBUDGET, 
RNYEAR, 
RNNUMBER, 
RNDATE, 
PROTOCOLNOTICE, 
PROTOCOLRESULTDATE, 
PROTOCOLDOCTYPE, 
PROTOCOLSALETYPE, 
NOTIFYDATE, 
EXECUTERACCREF, 
DOCBASEDATE, 
DOCBASENOTIFYDATE, 
DOCBASETEXT, 
DOCBASETYPE, 
DOCBASESUMMA, 
UNKNOWNAMOUNT, 
PROTOCOLREASON, 
DOCNUMBER, 
ADJUSTMENTDOCNUMBER, 
OLDDOCNUMBER, 
LOTMAXSUM, 
CLIENT_INN, 
CLIENT_INN20, 
CLIENT_NAME, 
EXECUTER_INN, 
EXECUTER_INN20, 
EXECUTER_NAME, 
EXECUTER_STATUS, 
EXECUTER_COUNTRY, 
EXECUTER_ADDRESS, 
EXECUTER_PHONE, 
REALID, 
ADJUSTMENTNUMBER, 
INNERNUMBER, 
SENDERIDKEY, 
SENDERRECORDIDKEY, 
REESTRVERSION, 
DOCTYPE, 
RNCLIENTID, 
INFONUMBER, 
STATEORDERINNERNUMBER, 
PROGINDEX, 
NOTE, 
PURPORTDOC, 
REESTRRECORDNUMBER
) AS
SELECT
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER
  FROM TB_agreements
  /

COMMIT WORK
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_ID
  INSTEAD OF DELETE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  cnt1$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BD_0 (TR_AGREEMENTS_BD)
-- Version 7.01.00.1
-- - - - - - - - - - - - -

  /*   5.0*/
  select count(id) into cnt1$ from agreements where (adjustmentref = :old.id) ;
  /*  .       .*/
  if (cnt1$ = 0) then
    delete from estimate where (recordindex = :old.id);
    delete from agreementsteps where (recordindex = :old.id);
    delete from paymentschedule where agreementref = :old.id;
        
  else
    RaiseException('ex_agr_cantdeladjustmented');
  END IF;

-- - - - - - - - - - - - -
-- BD_20 (TR_AGREEMENTS_BD_20)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  /*          */
  if ((:old.ProgIndex = 305)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 314)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  if ((:old.ProgIndex = 304)and(:old.AdjustmentNumber = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- DELETE
-- - - - - - - - - - - - -
  DELETE FROM TB_AGREEMENTS
  WHERE ID = :OLD.ID and (RVersion = :old.RVersion or RVersion is NULL and :old.RVersion is NULL);

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AD_10 (TR_AGREEMENTS_AD_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /*   LastAdjustment     */
    if ((:old.AdjustmentNumber > 0) and (:old.LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;    
    /*   LastAccepted     */    
    if ((:old.AdjustmentNumber > 0) and (:old.LastAccepted = 1)) then
        update Agreements set
            LastAccepted = 1,
            RVersion = -1
        where (ID = :old.AdjustmentRef);
    end if;    

-- - - - - - - - - - - - -
-- AD_200 (TR_AGREEMENTS_AD_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  /*        */
  delete from StateJumpHistory where DocID = :old.ID;

-- - - - - - - - - - - - -
-- AD_500 (TR_AGREEMENTS_AD_500)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  insert into DelRecIndexes(TableID, RecordId, DeleteDate, Summa, ProgIndex)
  values (110, :old.ID, SYSDATE, :old.AgreementSumma, :old.ProgIndex);

END;
/


CREATE OR REPLACE TRIGGER TR_AGREEMENTS_II
  INSTEAD OF INSERT
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
--
  tmp$ NUMBER (10);
  adjid$ NUMBER (10);
  adjdocnum$ tb_agreements.docnumber%TYPE;
  CurVal$ NUMBER (10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_AGREEMENTS_BI)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1.2*/
  /*    -*/
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$CardAdvancePercent is null) then 
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then 
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then 
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then 
    new$FinCardAdvance := 0;
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then 
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then 
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$Accepted is null) then 
    new$Accepted := 1;
  END IF;
  if (new$client_ref is null) then 
    new$client_ref := 0;
  END IF;
    
  /*  .    ,     */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) then
    BEGIN
      select fa.BudgetRef     into new$BudgetRef from FacialAcc_Cls fa
      where fa.Id = new$FacialAcc_Cls
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  /*    ,    */
  if ((new$BudgetRef is null) or (new$BudgetRef = 0)) 
  then 
    GetIntConst(-1, 3,new$BudgetRef);
  END IF;
    
  /*     
         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  /*    .  */
    
  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BI_5 (TR_AGREEMENTS_BI_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_10 (TR_AGREEMENTS_BI_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/

    /*    .*/
    if (new$InnerNumber is null) then
        RaiseException('EX_AGR_InnerNumsIsNull');
    end if;
    /*    */
    select max(AdjustmentNumber) into Tmp$
        from Agreements
        where (InnerNumber = new$InnerNumber);
        
    /*      ,   0*/
    if (Tmp$ is null) then
        new$AdjustmentNumber := 0;
    else
        new$AdjustmentNumber := Tmp$ + 1;
    end if;    

    /*        */
    if (((new$AgreementType = 0) and (new$AdjustmentNumber > 0)) or
        ((new$AgreementType = 1) and (new$AdjustmentNumber = 0))) then
        RaiseException('EX_AGR_AgrTypeViolation');
    end if;    

    /*        ,     */
    if ((new$Accepted = 0) and (new$AcceptDate is not null)) then
        new$LastAdjustment := 0;
    else
        new$LastAdjustment := 1;
    end if;    

    /*   ,       */
    if ((new$AcceptDate is not null) and (new$Accepted = 1)) then
        new$LastAccepted := 1;
    else
        new$LastAccepted := 0;
    end if;    



    /*    */
    if (new$AdjustmentNumber > 0) then
        /*      -    */
        select count(ID), max(ID), max(DocNumber)
            into Tmp$, AdjID$, AdjDocNum$
            from Agreements
            where (InnerNumber = new$InnerNumber) and (LastAccepted = 1);
            
        /*   ,  */
        if (Tmp$ <> 1) then
            RaiseException('EX_AGR_AdjustNotAccept');
        end if;    
        /*         ,  */
        select count(ID) into Tmp$
            from Agreements
            where (InnerNumber = new$InnerNumber) and (AcceptDate is null) and ROWNUM = 1;
        if (Tmp$ > 0) then
           RaiseException('EX_AGR_AdjustDuplicate');
        end if;   
        /* ,    ,    */
        new$AdjustmentRef := AdjID$;
        new$AdjustmentDocNumber := AdjDocNum$;
    else /*     */
        /*       (    )*/
        new$AdjustmentRef := null;
        new$AdjustmentDocNumber := null;
    end if;

-- - - - - - - - - - - - -
-- BI_20 (TR_AGREEMENTS_BI_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,     */
  if ((new$Client_INN   is null) and
      (new$Client_INN20 is null) and
      (new$Client_Name  is null))then
    BEGIN  
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;
    
  /*    -,     */
  if ((new$Executer_INN     is null) and
      (new$Executer_INN20   is null) and
      (new$Executer_Name    is null) and
      (new$Executer_Status  is null) and
      (new$Executer_Country is null) and
      (new$Executer_Address is null) and
      (new$Executer_Phone   is null))then
    BEGIN    
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END; 
  END IF;

-- - - - - - - - - - - - -
-- BI_40 (TR_AGREEMENTS_BI_40)
-- Create 06.08.2010
-- - - - - - - - - - - - -

  /*       */
  if (new$senderId is null) then 
    new$senderIdKey := -1;
  else
    new$senderIdKey := new$senderId;
  end if;

  if (new$SenderRecordID is null)then
    new$SenderRecordIDKey := new$ID;
  else
    new$SenderRecordIDKey := new$SenderRecordID;
  end if;       

-- - - - - - - - - - - - -
-- BI_50 (TR_AGREEMENTS_BI_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;  
    end if;

-- - - - - - - - - - - - -
-- BI_300 (tr_agreements_bi_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_400 (TR_AGREEMENTS_BI_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if ((new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;
          
    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_AGREEMENTS_BI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := USER;
  new$UpdaterUser := USER;

-- - - - - - - - - - - - -
-- BI_600 (agreements_realid_bi_600)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (new$realid is null) then 
    new$realid := new$id;
  END IF;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_AGREEMENTS (
    ID,
    SUMMA,
    AGREEMENTDATE,
    AGREEMENTENDDATE,
    EXECUTER_REF,
    CLIENT_REF,
    FACIALACC_CLS,
    AGREEMENTTYPE,
    ACCEPTED,
    ACCEPTDATE,
    CARDADVANCEPERCENT,
    CARDADVANCE,
    CLOSEDOC,
    CREATERUSER,
    CREATEDATE,
    UPDATEDATE,
    UPDATERUSER,
    BUDGETREF,
    LASTADJUSTMENT,
    LASTACCEPTED,
    FACT,
    REGION,
    CLOSEDATE,
    DELIVERYRULES,
    AGREEMENTSUMMA,
    AGREEMENTFINSUMMA,
    ADJUSTMENTREF,
    REESTRNUMBER,
    PAYMENTDATE,
    AGREEMENTCARDADVANCE,
    FINCARDADVANCE,
    STATEORDERREF,
    REJECTCLS,
    REJECTCAUSE,
    CRYPTOSTATUS,
    SENDERID,
    SENDERRECORDID,
    AGREEMENTBEGINDATE,
    PROTOCOLNUMBER,
    PROTOCOLDATE,
    REVIEWNOTE,
    DOCSTATEREF,
    RVERSION,
    EXPORTDATE,
    FSORGAN,
    FSBUDGETNAME,
    FSOFFBUDGET,
    RNYEAR,
    RNNUMBER,
    RNDATE,
    PROTOCOLNOTICE,
    PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE,
    NOTIFYDATE,
    EXECUTERACCREF,
    DOCBASEDATE,
    DOCBASENOTIFYDATE,
    DOCBASETEXT,
    DOCBASETYPE,
    DOCBASESUMMA,
    UNKNOWNAMOUNT,
    PROTOCOLREASON,
    DOCNUMBER,
    ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER,
    LOTMAXSUM,
    CLIENT_INN,
    CLIENT_INN20,
    CLIENT_NAME,
    EXECUTER_INN,
    EXECUTER_INN20,
    EXECUTER_NAME,
    EXECUTER_STATUS,
    EXECUTER_COUNTRY,
    EXECUTER_ADDRESS,
    EXECUTER_PHONE,
    REALID,
    ADJUSTMENTNUMBER,
    INNERNUMBER,
    SENDERIDKEY,
    SENDERRECORDIDKEY,
    REESTRVERSION,
    DOCTYPE,
    RNCLIENTID,
    INFONUMBER,
    STATEORDERINNERNUMBER,
    PROGINDEX,
    NOTE,
    PURPORTDOC,
    REESTRRECORDNUMBER
  ) VALUES (
    new$ID,
    new$SUMMA,
    new$AGREEMENTDATE,
    new$AGREEMENTENDDATE,
    new$EXECUTER_REF,
    new$CLIENT_REF,
    new$FACIALACC_CLS,
    new$AGREEMENTTYPE,
    new$ACCEPTED,
    new$ACCEPTDATE,
    new$CARDADVANCEPERCENT,
    new$CARDADVANCE,
    new$CLOSEDOC,
    new$CREATERUSER,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$UPDATERUSER,
    new$BUDGETREF,
    new$LASTADJUSTMENT,
    new$LASTACCEPTED,
    new$FACT,
    new$REGION,
    new$CLOSEDATE,
    new$DELIVERYRULES,
    new$AGREEMENTSUMMA,
    new$AGREEMENTFINSUMMA,
    new$ADJUSTMENTREF,
    new$REESTRNUMBER,
    new$PAYMENTDATE,
    new$AGREEMENTCARDADVANCE,
    new$FINCARDADVANCE,
    new$STATEORDERREF,
    new$REJECTCLS,
    new$REJECTCAUSE,
    new$CRYPTOSTATUS,
    new$SENDERID,
    new$SENDERRECORDID,
    new$AGREEMENTBEGINDATE,
    new$PROTOCOLNUMBER,
    new$PROTOCOLDATE,
    new$REVIEWNOTE,
    new$DOCSTATEREF,
    new$RVERSION,
    new$EXPORTDATE,
    new$FSORGAN,
    new$FSBUDGETNAME,
    new$FSOFFBUDGET,
    new$RNYEAR,
    new$RNNUMBER,
    new$RNDATE,
    new$PROTOCOLNOTICE,
    new$PROTOCOLRESULTDATE,
    new$PROTOCOLDOCTYPE,
    new$PROTOCOLSALETYPE,
    new$NOTIFYDATE,
    new$EXECUTERACCREF,
    new$DOCBASEDATE,
    new$DOCBASENOTIFYDATE,
    new$DOCBASETEXT,
    new$DOCBASETYPE,
    new$DOCBASESUMMA,
    new$UNKNOWNAMOUNT,
    new$PROTOCOLREASON,
    new$DOCNUMBER,
    new$ADJUSTMENTDOCNUMBER,
    new$OLDDOCNUMBER,
    new$LOTMAXSUM,
    new$CLIENT_INN,
    new$CLIENT_INN20,
    new$CLIENT_NAME,
    new$EXECUTER_INN,
    new$EXECUTER_INN20,
    new$EXECUTER_NAME,
    new$EXECUTER_STATUS,
    new$EXECUTER_COUNTRY,
    new$EXECUTER_ADDRESS,
    new$EXECUTER_PHONE,
    new$REALID,
    new$ADJUSTMENTNUMBER,
    new$INNERNUMBER,
    new$SENDERIDKEY,
    new$SENDERRECORDIDKEY,
    new$REESTRVERSION,
    new$DOCTYPE,
    new$RNCLIENTID,
    new$INFONUMBER,
    new$STATEORDERINNERNUMBER,
    new$PROGINDEX,
    new$NOTE,
    new$PURPORTDOC,
    new$REESTRRECORDNUMBER);

-- - - - - - - - - - - - -
-- AI_10 (TR_AGREEMENTS_AI_10)
-- Last update 05.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    if ((new$AdjustmentNumber > 0) and (new$LastAdjustment = 1)) then
        update Agreements set
            LastAdjustment = 0,
            RVersion = -1
        where (ID = new$AdjustmentRef);        
        if (new$LastAccepted = 1) then
            update Agreements set
                LastAccepted = 0,
                RVersion = -1
            where (ID = new$AdjustmentRef);
        end if;    
    end if;

-- - - - - - - - - - - - -
-- AI_500 (TR_AGREEMENTS_AI_500)
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   DELETE FROM DelRecIndexes
         WHERE (TableID = 110) AND (RecordID = new$ID);

END;
/

CREATE OR REPLACE TRIGGER TR_AGREEMENTS_IU
  INSTEAD OF UPDATE
  ON AGREEMENTS
  FOR EACH ROW
DECLARE
  new$ID AGREEMENTS.ID%TYPE := :NEW.ID;
  new$SUMMA AGREEMENTS.SUMMA%TYPE := :NEW.SUMMA;
  new$AGREEMENTDATE AGREEMENTS.AGREEMENTDATE%TYPE := :NEW.AGREEMENTDATE;
  new$AGREEMENTENDDATE AGREEMENTS.AGREEMENTENDDATE%TYPE := :NEW.AGREEMENTENDDATE;
  new$EXECUTER_REF AGREEMENTS.EXECUTER_REF%TYPE := :NEW.EXECUTER_REF;
  new$CLIENT_REF AGREEMENTS.CLIENT_REF%TYPE := :NEW.CLIENT_REF;
  new$FACIALACC_CLS AGREEMENTS.FACIALACC_CLS%TYPE := :NEW.FACIALACC_CLS;
  new$AGREEMENTTYPE AGREEMENTS.AGREEMENTTYPE%TYPE := :NEW.AGREEMENTTYPE;
  new$ACCEPTED AGREEMENTS.ACCEPTED%TYPE := :NEW.ACCEPTED;
  new$ACCEPTDATE AGREEMENTS.ACCEPTDATE%TYPE := :NEW.ACCEPTDATE;
  new$CARDADVANCEPERCENT AGREEMENTS.CARDADVANCEPERCENT%TYPE := :NEW.CARDADVANCEPERCENT;
  new$CARDADVANCE AGREEMENTS.CARDADVANCE%TYPE := :NEW.CARDADVANCE;
  new$CLOSEDOC AGREEMENTS.CLOSEDOC%TYPE := :NEW.CLOSEDOC;
  new$CREATERUSER AGREEMENTS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$CREATEDATE AGREEMENTS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE AGREEMENTS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$UPDATERUSER AGREEMENTS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$BUDGETREF AGREEMENTS.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$LASTADJUSTMENT AGREEMENTS.LASTADJUSTMENT%TYPE := :NEW.LASTADJUSTMENT;
  new$LASTACCEPTED AGREEMENTS.LASTACCEPTED%TYPE := :NEW.LASTACCEPTED;
  new$FACT AGREEMENTS.FACT%TYPE := :NEW.FACT;
  new$REGION AGREEMENTS.REGION%TYPE := :NEW.REGION;
  new$CLOSEDATE AGREEMENTS.CLOSEDATE%TYPE := :NEW.CLOSEDATE;
  new$DELIVERYRULES AGREEMENTS.DELIVERYRULES%TYPE := :NEW.DELIVERYRULES;
  new$AGREEMENTSUMMA AGREEMENTS.AGREEMENTSUMMA%TYPE := :NEW.AGREEMENTSUMMA;
  new$AGREEMENTFINSUMMA AGREEMENTS.AGREEMENTFINSUMMA%TYPE := :NEW.AGREEMENTFINSUMMA;
  new$ADJUSTMENTREF AGREEMENTS.ADJUSTMENTREF%TYPE := :NEW.ADJUSTMENTREF;
  new$REESTRNUMBER AGREEMENTS.REESTRNUMBER%TYPE := :NEW.REESTRNUMBER;
  new$PAYMENTDATE AGREEMENTS.PAYMENTDATE%TYPE := :NEW.PAYMENTDATE;
  new$AGREEMENTCARDADVANCE AGREEMENTS.AGREEMENTCARDADVANCE%TYPE := :NEW.AGREEMENTCARDADVANCE;
  new$FINCARDADVANCE AGREEMENTS.FINCARDADVANCE%TYPE := :NEW.FINCARDADVANCE;
  new$STATEORDERREF AGREEMENTS.STATEORDERREF%TYPE := :NEW.STATEORDERREF;
  new$REJECTCLS AGREEMENTS.REJECTCLS%TYPE := :NEW.REJECTCLS;
  new$REJECTCAUSE AGREEMENTS.REJECTCAUSE%TYPE := :NEW.REJECTCAUSE;
  new$CRYPTOSTATUS AGREEMENTS.CRYPTOSTATUS%TYPE := :NEW.CRYPTOSTATUS;
  new$SENDERID AGREEMENTS.SENDERID%TYPE := :NEW.SENDERID;
  new$SENDERRECORDID AGREEMENTS.SENDERRECORDID%TYPE := :NEW.SENDERRECORDID;
  new$AGREEMENTBEGINDATE AGREEMENTS.AGREEMENTBEGINDATE%TYPE := :NEW.AGREEMENTBEGINDATE;
  new$PROTOCOLNUMBER AGREEMENTS.PROTOCOLNUMBER%TYPE := :NEW.PROTOCOLNUMBER;
  new$PROTOCOLDATE AGREEMENTS.PROTOCOLDATE%TYPE := :NEW.PROTOCOLDATE;
  new$REVIEWNOTE AGREEMENTS.REVIEWNOTE%TYPE := :NEW.REVIEWNOTE;
  new$DOCSTATEREF AGREEMENTS.DOCSTATEREF%TYPE := :NEW.DOCSTATEREF;
  new$RVERSION AGREEMENTS.RVERSION%TYPE := :NEW.RVERSION;
  new$EXPORTDATE AGREEMENTS.EXPORTDATE%TYPE := :NEW.EXPORTDATE;
  new$FSORGAN AGREEMENTS.FSORGAN%TYPE := :NEW.FSORGAN;
  new$FSBUDGETNAME AGREEMENTS.FSBUDGETNAME%TYPE := :NEW.FSBUDGETNAME;
  new$FSOFFBUDGET AGREEMENTS.FSOFFBUDGET%TYPE := :NEW.FSOFFBUDGET;
  new$RNYEAR AGREEMENTS.RNYEAR%TYPE := :NEW.RNYEAR;
  new$RNNUMBER AGREEMENTS.RNNUMBER%TYPE := :NEW.RNNUMBER;
  new$RNDATE AGREEMENTS.RNDATE%TYPE := :NEW.RNDATE;
  new$PROTOCOLNOTICE AGREEMENTS.PROTOCOLNOTICE%TYPE := :NEW.PROTOCOLNOTICE;
  new$PROTOCOLRESULTDATE AGREEMENTS.PROTOCOLRESULTDATE%TYPE := :NEW.PROTOCOLRESULTDATE;
  new$PROTOCOLDOCTYPE AGREEMENTS.PROTOCOLDOCTYPE%TYPE := :NEW.PROTOCOLDOCTYPE;
  new$PROTOCOLSALETYPE AGREEMENTS.PROTOCOLSALETYPE%TYPE := :NEW.PROTOCOLSALETYPE;
  new$NOTIFYDATE AGREEMENTS.NOTIFYDATE%TYPE := :NEW.NOTIFYDATE;
  new$EXECUTERACCREF AGREEMENTS.EXECUTERACCREF%TYPE := :NEW.EXECUTERACCREF;
  new$DOCBASEDATE AGREEMENTS.DOCBASEDATE%TYPE := :NEW.DOCBASEDATE;
  new$DOCBASENOTIFYDATE AGREEMENTS.DOCBASENOTIFYDATE%TYPE := :NEW.DOCBASENOTIFYDATE;
  new$DOCBASETEXT AGREEMENTS.DOCBASETEXT%TYPE := :NEW.DOCBASETEXT;
  new$DOCBASETYPE AGREEMENTS.DOCBASETYPE%TYPE := :NEW.DOCBASETYPE;
  new$DOCBASESUMMA AGREEMENTS.DOCBASESUMMA%TYPE := :NEW.DOCBASESUMMA;
  new$UNKNOWNAMOUNT AGREEMENTS.UNKNOWNAMOUNT%TYPE := :NEW.UNKNOWNAMOUNT;
  new$PROTOCOLREASON AGREEMENTS.PROTOCOLREASON%TYPE := :NEW.PROTOCOLREASON;
  new$DOCNUMBER AGREEMENTS.DOCNUMBER%TYPE := :NEW.DOCNUMBER;
  new$ADJUSTMENTDOCNUMBER AGREEMENTS.ADJUSTMENTDOCNUMBER%TYPE := :NEW.ADJUSTMENTDOCNUMBER;
  new$OLDDOCNUMBER AGREEMENTS.OLDDOCNUMBER%TYPE := :NEW.OLDDOCNUMBER;
  new$LOTMAXSUM AGREEMENTS.LOTMAXSUM%TYPE := :NEW.LOTMAXSUM;
  new$CLIENT_INN AGREEMENTS.CLIENT_INN%TYPE := :NEW.CLIENT_INN;
  new$CLIENT_INN20 AGREEMENTS.CLIENT_INN20%TYPE := :NEW.CLIENT_INN20;
  new$CLIENT_NAME AGREEMENTS.CLIENT_NAME%TYPE := :NEW.CLIENT_NAME;
  new$EXECUTER_INN AGREEMENTS.EXECUTER_INN%TYPE := :NEW.EXECUTER_INN;
  new$EXECUTER_INN20 AGREEMENTS.EXECUTER_INN20%TYPE := :NEW.EXECUTER_INN20;
  new$EXECUTER_NAME AGREEMENTS.EXECUTER_NAME%TYPE := :NEW.EXECUTER_NAME;
  new$EXECUTER_STATUS AGREEMENTS.EXECUTER_STATUS%TYPE := :NEW.EXECUTER_STATUS;
  new$EXECUTER_COUNTRY AGREEMENTS.EXECUTER_COUNTRY%TYPE := :NEW.EXECUTER_COUNTRY;
  new$EXECUTER_ADDRESS AGREEMENTS.EXECUTER_ADDRESS%TYPE := :NEW.EXECUTER_ADDRESS;
  new$EXECUTER_PHONE AGREEMENTS.EXECUTER_PHONE%TYPE := :NEW.EXECUTER_PHONE;
  new$REALID AGREEMENTS.REALID%TYPE := :NEW.REALID;
  new$ADJUSTMENTNUMBER AGREEMENTS.ADJUSTMENTNUMBER%TYPE := :NEW.ADJUSTMENTNUMBER;
  new$INNERNUMBER AGREEMENTS.INNERNUMBER%TYPE := :NEW.INNERNUMBER;
  new$SENDERIDKEY AGREEMENTS.SENDERIDKEY%TYPE := :NEW.SENDERIDKEY;
  new$SENDERRECORDIDKEY AGREEMENTS.SENDERRECORDIDKEY%TYPE := :NEW.SENDERRECORDIDKEY;
  new$REESTRVERSION AGREEMENTS.REESTRVERSION%TYPE := :NEW.REESTRVERSION;
  new$DOCTYPE AGREEMENTS.DOCTYPE%TYPE := :NEW.DOCTYPE;
  new$RNCLIENTID AGREEMENTS.RNCLIENTID%TYPE := :NEW.RNCLIENTID;
  new$INFONUMBER AGREEMENTS.INFONUMBER%TYPE := :NEW.INFONUMBER;
  new$STATEORDERINNERNUMBER AGREEMENTS.STATEORDERINNERNUMBER%TYPE := :NEW.STATEORDERINNERNUMBER;
  new$PROGINDEX AGREEMENTS.PROGINDEX%TYPE := :NEW.PROGINDEX;
  new$NOTE AGREEMENTS.NOTE%TYPE := :NEW.NOTE;
  new$PURPORTDOC AGREEMENTS.PURPORTDOC%TYPE := :NEW.PURPORTDOC;
  new$REESTRRECORDNUMBER AGREEMENTS.REESTRRECORDNUMBER%TYPE := :NEW.REESTRRECORDNUMBER;
--
  MaxNumber$ NUMBER (10);
  CurVal$ NUMBER (10);
  CNT$1 NUMBER(10);
  DetCount$ NUMBER(10);
  CountAcc$ NUMBER(10);
  rnClientID1$ VARCHAR2(15);
  rnYear1$ VARCHAR2(15);
  rnNumber1$ VARCHAR2(15);
  ReestrVersion1$ VARCHAR2(15);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_AGREEMENTS_BU)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   3.1*/
  /*    -*/
  if (new$CardAdvancePercent is null) then 
    new$CardAdvancePercent := 0;
  END IF;
  if (new$CardAdvance is null) then 
    new$CardAdvance := 0;
  END IF;
  if (new$AgreementCardAdvance is null) then 
    new$AgreementCardAdvance := 0;
  END IF;
  if (new$FinCardAdvance is null) then 
    new$FinCardAdvance := 0;    
  END IF;
  if (new$Summa is null) then 
    new$Summa := 0;
  END IF;
  if (new$AgreementSumma is null) then 
    new$AgreementSumma := 0;
  END IF;
  if (new$AgreementFinSumma is null) then 
    new$AgreementFinSumma := 0;
  END IF;
  if (new$FacialAcc_Cls is null) then 
    new$FacialAcc_Cls := 0;
  END IF;
  if (new$Fact is null) then 
    new$Fact := 0;
  END IF;
  if (new$Region is null) then 
    new$Region := 0;
  END IF;
  if (new$UnknownAmount is null) then 
    new$UnknownAmount := 0;
  END IF;
  if (new$client_ref is null) then 
    new$client_ref := 0;
  END IF;
  /*     */
  if (new$BudgetRef <> :old.BudgetRef) then
    if ( not((new$BudgetRef is null) and (:old.BudgetRef is null)) ) then
      select count(ID)       into DetCount$ from AgreementSteps where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');
      END IF;
      select count(ID)       into DetCount$ from Estimate where RecordIndex = :old.ID
      ;
      if (DetCount$ > 0) then
        RaiseException('Ex_CantModufyBudget');    
      END IF;
    END IF;
  END IF;
  /*         -   InnerNumber*/
  if (((new$ProgIndex = 305) or (new$ProgIndex = 304) or (new$ProgIndex = 314)) and (new$InnerNumber is null)) then
    new$InnerNumber := GEN_ID('G_AgreementNumber',1);
  END IF;
  /*   */
  if (new$DocType is null) then 
    new$DocType := 0;
  END IF;
  /*    .  */
    
  new$stateorderinnernumber := null;
  if (new$stateorderref is not null) then
    BEGIN
      select
      innernumber
      into new$stateorderinnernumber     from agreements
      where
      id = new$stateorderref
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;

-- - - - - - - - - - - - -
-- BU_3 (TR_AGREEMENTS_BU_3)
-- Create 03.12.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*            */
   new$AdjustmentRef := :OLD.AdjustmentRef;

-- - - - - - - - - - - - -
-- BU_5 (TR_AGREEMENTS_BU_5)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*     ,                */
  if (new$DocStateRef is null) then
    if (new$AcceptDate is null or new$RejectCls is null) then
      new$Accepted := 1;
          
    else
      new$Accepted := 0;
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_10 (TR_AGREEMENTS_BU_10)
-- Last update 08.02.2010
-- - - - - - - - - - - - -

/*   5.0*/
    /* ,      ,   */
    if ((new$InnerNumber <> :old.InnerNumber) or 
        (new$AdjustmentNumber <> :old.AdjustmentNumber) or
        (new$AgreementType <> :old.AgreementType)) then
        RaiseException('EX_AGR_ChangeInnerNums');
    end if;    
    
    /*    !!!*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 0)) and 
        ((new$Accepted = 1) or (new$AcceptDate is null))) then
        RaiseException('EX_RollbackCancel');
    end if;    
    
    /*   ,     LastAccepted*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 1)) or 
        ((:old.Accepted = 0) and (new$Accepted = 1) and (new$AcceptDate is not null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 1;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;    
    end if;
    
    /*    ,     LastAccepted*/
    if (((:old.AcceptDate is not null) and (:old.Accepted = 1)) and
        ((new$Accepted = 0) or (new$AcceptDate is null))) then
        /*  LastAccepted         */
        if (new$LastAdjustment = 1) then
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;    
    end if;
    
    /*   ,     LastAdjustment*/
    if (((:old.AcceptDate is null) and (new$AcceptDate is not null) and (new$Accepted = 0)) or 
        ((:old.Accepted = 1) and (new$Accepted = 0) and (new$AcceptDate is not null))) then
        
        if (new$LastAdjustment = 1) then
            new$LastAdjustment := 0;
            new$LastAccepted := 0;
        else
            RaiseException('EX_AGR_ChangeStateAdjust');
        end if;    

        SELECT Max(AdjustmentNumber) INTO MaxNumber$ FROm AgreementS 
        WHERE (InnerNumber = new$InnerNumber);
        /*    ,     */
        if ((new$adjustmentNumber=0) and (MaxNumber$<>0)) then
          RaiseException('EX_Agr_PrimaryAgrHasNotify');
        end if;
    end if;

-- - - - - - - - - - - - -
-- BU_20 (TR_AGREEMENTS_BU_20)
-- Create 21.05.2009
-- - - - - - - - - - - - -

  /*    -,      */
  if ((new$Client_Ref <> :old.Client_Ref) and
      (((new$Client_INN is null) and
        (:old.Client_INN is null)) or
       (new$Client_INN = :old.Client_INN)) and
      (((new$Client_INN20 is null) and
        (:old.Client_INN20 is null)) or
       (new$Client_INN20 = :old.Client_INN20)) and
      (new$Client_Name = :old.Client_Name)) then
    BEGIN  
      select
        o.INN,
        o.INN20,
        o.Name
      into
        new$Client_INN,
        new$Client_INN20,
        new$Client_Name
      from Organizations o
      where o.Id=new$Client_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Client_INN := NULL;
        new$Client_INN20 := NULL;
        new$Client_Name := NULL;
    END;
  END IF;
      
  /*    -,      */
  if ((new$Executer_Ref <> :old.Executer_Ref) and
      (((new$Executer_INN is null) and
        (:old.Executer_INN is null)) or
       (new$Executer_INN = :old.Executer_INN)) and
      (((new$Executer_INN20 is null) and
        (:old.Executer_INN20 is null)) or
       (new$Executer_INN20 = :old.Executer_INN20)) and
      (new$Executer_Name = :old.Executer_Name) and
      (((new$Executer_Status is null) and
        (:old.Executer_Status is null)) or
       (new$Executer_Status = :old.Executer_Status)) and
      (((new$Executer_Country is null) and
        (:old.Executer_Country is null)) or
       (new$Executer_Country = :old.Executer_Country)) and
      (((new$Executer_Address is null) and
        (:old.Executer_Address is null)) or
       (new$Executer_Address = :old.Executer_Address)) and
      (((new$Executer_Phone is null) and
        (:old.Executer_Phone is null)) or
       (new$Executer_Phone = :old.Executer_Phone))) then
     BEGIN    
      select
        o.INN,
        o.INN20,
        o.Name,
        o.SupplierStatus,
        o.Country,
        o.Address,
        o.Phone
      into
        new$Executer_INN,
        new$Executer_INN20,
        new$Executer_Name,
        new$Executer_Status,
        new$Executer_Country,
        new$Executer_Address,
        new$Executer_Phone
      from Organizations o
      where o.Id=new$Executer_Ref;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN
        new$Executer_INN := NULL;
        new$Executer_INN20 := NULL;
        new$Executer_Name := NULL;
        new$Executer_Status := NULL;
        new$Executer_Country := NULL;
        new$Executer_Address := NULL;
        new$Executer_Phone := NULL;
    END; 
  END IF;

-- - - - - - - - - - - - -
-- BU_50 (TR_AGREEMENTS_BU_50)
-- Create 06.08.2010
-- - - - - - - - - - - - -

    if (new$InnerNumber is not null) then
        CurVal$ := gen_id('G_AgreementNumber', 0);
        if (CurVal$ < new$InnerNumber) then
          CurVal$ := gen_id('G_AgreementNumber', new$InnerNumber - CurVal$);
        end if;  
    end if;

-- - - - - - - - - - - - -
-- BU_60 (tr_agreements_bu_60)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  /*        ,     */
  if (:old.accepted = 1 and new$accepted = 0 and new$acceptdate is not null and new$adjustmentnumber = 0) then
    SELECT COUNT(*) INTO CNT$1
    from executiondocumentscaption
    where
    (            agreementinnernumber = new$innernumber
    and (accepted <> 0 or acceptdate is null)) AND (ROWNUM = 1);
    if ((CNT$1<> 0)) then
      RaiseException('EX_Agr_CannotReject');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_200 (TR_AGREEMENTS_BU_200)
-- Create 04.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   /*       */
   IF (new$DocStateRef <> :OLD.DocStateRef) THEN
      INSERT INTO StateJumpHistory
                  (DocID, BeginStateRef, EndStateRef
                  )
           VALUES (new$id, :OLD.DocStateRef, new$DocStateRef
                  );
   END IF;

-- - - - - - - - - - - - -
-- BU_300 (tr_agreements_bu_300)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if (new$ExecuterAccRef is not null) then
    select count(ID)
    into CountAcc$     from org_accounts oa
    where oa.id = new$ExecuterAccRef and oa.Org_ref = new$Executer_Ref
    ;
    if (CountAcc$ = 0) then
      RaiseException('EX_AGR_ACCORGCHECK');  
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_400 (TR_AGREEMENTS_BU_400)
-- Version 10.00.00.1
-- - - - - - - - - - - - -

  if (((new$rnClientID <> :old.rnClientID) or (new$rnYear <> :old.rnYear) or
  (new$rnNumber <> :old.rnNumber) or (new$ReestrVersion <> :old.ReestrVersion)) and
  (new$rnClientID is not null) and (new$rnYear is not null) and (new$rnNumber is not null)) then

    rnClientID1$ := new$rnClientID;
    rnYear1$ := new$rnYear;
    rnNumber1$ := new$rnNumber;
    ReestrVersion1$ := new$ReestrVersion;
    while (LENGTH(rnClientID1$) < 11) LOOP
      rnClientID1$ := '0' || rnClientID1$;
    END LOOP;
    while (LENGTH(rnNumber1$) < 6) LOOP
      rnNumber1$ := '0' || rnNumber1$;
    END LOOP;
    if (LENGTH(ReestrVersion1$) < 2) then
      ReestrVersion1$ := '0' || ReestrVersion1$;
    END IF;
    /*  ReestrRecordNumber*/
    if (new$ReestrVersion is null) then
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$;
          
    else
      new$ReestrRecordNumber := rnClientID1$ || rnYear1$ || rnNumber1$ || ReestrVersion1$;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- BU_700 (TR_AGREEMENTS_BU_700)
-- Create 14.10.2004
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$RVersion IS NULL) THEN
      new$RVersion := 1;
   ELSE
      IF ((new$RVersion = -1) AND (:OLD.RVersion <> -1)) THEN
         new$RVersion := :OLD.RVersion;
      ELSE
         new$RVersion := :OLD.RVersion + 1;
      END IF;
   END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_AGREEMENTS SET
    ID = new$ID,
    SUMMA = new$SUMMA,
    AGREEMENTDATE = new$AGREEMENTDATE,
    AGREEMENTENDDATE = new$AGREEMENTENDDATE,
    EXECUTER_REF = new$EXECUTER_REF,
    CLIENT_REF = new$CLIENT_REF,
    FACIALACC_CLS = new$FACIALACC_CLS,
    AGREEMENTTYPE = new$AGREEMENTTYPE,
    ACCEPTED = new$ACCEPTED,
    ACCEPTDATE = new$ACCEPTDATE,
    CARDADVANCEPERCENT = new$CARDADVANCEPERCENT,
    CARDADVANCE = new$CARDADVANCE,
    CLOSEDOC = new$CLOSEDOC,
    CREATERUSER = new$CREATERUSER,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    UPDATERUSER = new$UPDATERUSER,
    BUDGETREF = new$BUDGETREF,
    LASTADJUSTMENT = new$LASTADJUSTMENT,
    LASTACCEPTED = new$LASTACCEPTED,
    FACT = new$FACT,
    REGION = new$REGION,
    CLOSEDATE = new$CLOSEDATE,
    DELIVERYRULES = new$DELIVERYRULES,
    AGREEMENTSUMMA = new$AGREEMENTSUMMA,
    AGREEMENTFINSUMMA = new$AGREEMENTFINSUMMA,
    ADJUSTMENTREF = new$ADJUSTMENTREF,
    REESTRNUMBER = new$REESTRNUMBER,
    PAYMENTDATE = new$PAYMENTDATE,
    AGREEMENTCARDADVANCE = new$AGREEMENTCARDADVANCE,
    FINCARDADVANCE = new$FINCARDADVANCE,
    STATEORDERREF = new$STATEORDERREF,
    REJECTCLS = new$REJECTCLS,
    REJECTCAUSE = new$REJECTCAUSE,
    CRYPTOSTATUS = new$CRYPTOSTATUS,
    SENDERID = new$SENDERID,
    SENDERRECORDID = new$SENDERRECORDID,
    AGREEMENTBEGINDATE = new$AGREEMENTBEGINDATE,
    PROTOCOLNUMBER = new$PROTOCOLNUMBER,
    PROTOCOLDATE = new$PROTOCOLDATE,
    REVIEWNOTE = new$REVIEWNOTE,
    DOCSTATEREF = new$DOCSTATEREF,
    RVERSION = new$RVERSION,
    EXPORTDATE = new$EXPORTDATE,
    FSORGAN = new$FSORGAN,
    FSBUDGETNAME = new$FSBUDGETNAME,
    FSOFFBUDGET = new$FSOFFBUDGET,
    RNYEAR = new$RNYEAR,
    RNNUMBER = new$RNNUMBER,
    RNDATE = new$RNDATE,
    PROTOCOLNOTICE = new$PROTOCOLNOTICE,
    PROTOCOLRESULTDATE = new$PROTOCOLRESULTDATE,
    PROTOCOLDOCTYPE = new$PROTOCOLDOCTYPE,
    PROTOCOLSALETYPE = new$PROTOCOLSALETYPE,
    NOTIFYDATE = new$NOTIFYDATE,
    EXECUTERACCREF = new$EXECUTERACCREF,
    DOCBASEDATE = new$DOCBASEDATE,
    DOCBASENOTIFYDATE = new$DOCBASENOTIFYDATE,
    DOCBASETEXT = new$DOCBASETEXT,
    DOCBASETYPE = new$DOCBASETYPE,
    DOCBASESUMMA = new$DOCBASESUMMA,
    UNKNOWNAMOUNT = new$UNKNOWNAMOUNT,
    PROTOCOLREASON = new$PROTOCOLREASON,
    DOCNUMBER = new$DOCNUMBER,
    ADJUSTMENTDOCNUMBER = new$ADJUSTMENTDOCNUMBER,
    OLDDOCNUMBER = new$OLDDOCNUMBER,
    LOTMAXSUM = new$LOTMAXSUM,
    CLIENT_INN = new$CLIENT_INN,
    CLIENT_INN20 = new$CLIENT_INN20,
    CLIENT_NAME = new$CLIENT_NAME,
    EXECUTER_INN = new$EXECUTER_INN,
    EXECUTER_INN20 = new$EXECUTER_INN20,
    EXECUTER_NAME = new$EXECUTER_NAME,
    EXECUTER_STATUS = new$EXECUTER_STATUS,
    EXECUTER_COUNTRY = new$EXECUTER_COUNTRY,
    EXECUTER_ADDRESS = new$EXECUTER_ADDRESS,
    EXECUTER_PHONE = new$EXECUTER_PHONE,
    REALID = new$REALID,
    ADJUSTMENTNUMBER = new$ADJUSTMENTNUMBER,
    INNERNUMBER = new$INNERNUMBER,
    SENDERIDKEY = new$SENDERIDKEY,
    SENDERRECORDIDKEY = new$SENDERRECORDIDKEY,
    REESTRVERSION = new$REESTRVERSION,
    DOCTYPE = new$DOCTYPE,
    RNCLIENTID = new$RNCLIENTID,
    INFONUMBER = new$INFONUMBER,
    STATEORDERINNERNUMBER = new$STATEORDERINNERNUMBER,
    PROGINDEX = new$PROGINDEX,
    NOTE = new$NOTE,
    PURPORTDOC = new$PURPORTDOC,
    REESTRRECORDNUMBER = new$REESTRRECORDNUMBER
  WHERE ID = :OLD.ID
      AND (RVersion = :OLD.RVersion
           OR RVersion IS NULL AND :OLD.RVersion IS NULL
          );

   IF SQL%ROWCOUNT <> 1 THEN
      RaiseException ('EX_RECORDCHANGED');
   END IF;

-- - - - - - - - - - - - -
-- AU_10 (TR_AGREEMENTS_AU_10)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*   6.0*/
  /*      */
  /*     ,       */
  if ((new$AdjustmentNumber > 0) and (new$LastAccepted <> :old.LastAccepted) and (:old.LastAdjustment = 1)) then
    update Agreements set
    LastAccepted = :old.LastAccepted,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*       LastAdjustment     */
  if ((new$AdjustmentNumber > 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0) and
  (new$AcceptDate is not null) and (new$Accepted = 0)) then
    update Agreements set
    LastAdjustment = 1,
    RVersion = -1
    where (ID = new$AdjustmentRef);
  END IF;
  /*          */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 304)or(new$ProgIndex = 314)))then
    update Estimate
    set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    (RecordIndex = new$Id);
  END IF;
  /*         */
  if ((new$FacialAcc_Cls <> :old.FacialAcc_Cls) and ((new$ProgIndex = 305) or (new$ProgIndex = 314))) then
    update paymentschedule set
    FacialAcc_Cls = new$FacialAcc_Cls,
    RVersion = -1
    where
    AgreementRef = new$ID and
    ProgIndex in (317, 318);

  END IF;

-- - - - - - - - - - - - -
-- AU_20 (TR_AGREEMENTS_AU_20)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  /*      */
  if ((new$ProgIndex = 305) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null
    where
    StateOrder = :old.ID;
  END IF;
  /*      */
  if ((new$ProgIndex = 314) and (new$AdjustmentNumber = 0) and
  (new$Accepted = 0) and (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    StateOrder = null,
    Agreement = null
    where
    StateOrder = :old.ID;
  END IF;
  /*     */
  if ((:old.ProgIndex = 304) and (new$AdjustmentNumber = 0) and (new$Accepted = 0) and
  (:old.LastAdjustment = 1) and (new$LastAdjustment = 0)) then
    update tenderresultcaption set
    Agreement = null
    where
    Agreement = :old.ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_30 (TR_AGREEMENTS_AU_30)
-- Version 8.00.00.1
-- - - - - - - - - - - - -

  if ((new$DocStateRef is null) and /*     ,        */
  ((new$ProgIndex = 304) or (new$ProgIndex = 314)) and 
  ((new$Accepted <> :old.Accepted) or 
  (new$AcceptDate is not null and :old.AcceptDate is null) or 
  (new$AcceptDate is null and :old.AcceptDate is not null) or
  (new$AcceptDate is not null and :old.AcceptDate is not null and new$AcceptDate <> :old.AcceptDate))) then
    update paymentschedule set
    Accepted = new$Accepted,
    AcceptDate = new$AcceptDate
    where AgreementRef=new$ID;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_AGREEMENTS_AU_500)
-- Create 28.04.2005
-- Last update 19.05.2005
-- - - - - - - - - - - - -

   IF (new$ID <> :OLD.ID) THEN
      INSERT INTO DelRecIndexes
                  (TableID, RecordId, DeleteDate
                  )
           VALUES (110, :OLD.ID, SYSDATE
                  );

      DELETE FROM DelRecIndexes
            WHERE (TableID = 110) AND (RecordId = new$ID);
   END IF;

END;
/

COMMIT WORK
/

ALTER TRIGGER TR_AGREEMENTS_BU_500 ENABLE
/

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- enable_TR_BUDSTRUCTRIGHTS_BU_500.sql
-- #########################################################
-- #########################################################

/*   TR_BUDSTRUCTRIGHTS_BU_500,     10.0 */
ALTER TRIGGER TR_BUDSTRUCTRIGHTS_BU_500 ENABLE
/
commit work 
/

-- #########################################################
-- #########################################################
-- FixRightKind.sql
-- #########################################################
-- #########################################################

/*    RightRef - RightKindRef -   MultiAdm 10.
*/
update UsersRights ur set
  RightKindRef = (select Min(RightKindRef) from DBRIGHTS dr where (dr.Id = ur.RightRef))
where
  ur.RightKindRef not in (select RightKindRef from DBRIGHTS dr where (dr.Id = ur.RightRef))
/
commit work 
/


-- #########################################################
-- #########################################################
-- UpdDocFields_10.20.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 101000 - 102000.     15.09.2015 08:37:48.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
		    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
	      PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_)
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(206, 268, '   ()', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'__') ;

CALL ImportDocType(211, 275, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(211, ' ', '{AE8281A0-BE7F-4F3A-90BD-A7831E8D842F}', '') ;

CALL ImportDocType(212, 276, '  , ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(212, '  , ', '{B743C24B-6E28-4C9C-B3CA-16AC6E529D07}', '') ;

CALL ImportDocType(302, 63, '  \', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(304, 64, '  ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(308, 67, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL UpdateInterfaces(308, ' ', '{B50F2C63-9CF4-42C3-8062-E355EABD53E4}', '') ;

CALL ImportDocType(324, 76, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(1816, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1816, '  ', '{584B1826-AD94-47DC-A420-B5E42F2CA7D7}', '') ;

CALL ImportDocType(5301, 0, '   ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(5301, '   ', '{FF462FFC-4DA8-4A24-B2BA-0B6478238E00}', '') ;

CALL ImportDocType(5501, 312, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(5502, 313, '   ', 0, 'CorrectionCaption', 0,-1,'',10100,'_') ;

CALL ImportDocType(9601, 0, '', 0, 'ORGANIZATIONS', 0,0,'',20100,'') ;

CALL ImportDocType(9926, 0, '   ', 0, 'WritNotifyCls ', 0,0,'',10200,'') ;

CALL UpdateInterfaces(9926, '   ', '{89CAEE9C-9516-4EE2-8A4B-CB0BFA9165AB}', '') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL FIELDSINFO_DELETE(32935) ;

DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 314) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_	      NUMBER,
   FIELDINFOREF_      NUMBER
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
			 FIELDINFOREF = FIELDINFOREF_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
CALL DeleteFields(20300025) ;

CALL DeleteFields(980510013) ;

CALL DeleteConst(0, 0, 8) ;

CALL DeleteFields(991610123) ;

CALL DeleteConst(0, 0, 8) ;

CALL DeleteFields(991610124) ;

CALL DeleteConst(0, 0, 8) ;

CALL DeleteFields(991610125) ;

--    , (1)
CALL ImportField(10111023, '', 'REGIONCLS', '', ' ', 1, 101, 1, 0, ',', 0, 17831) ;

CALL ImportField(10112056, '', 'REGIONCLS', '', ' ', 1, 101, 2, 0, ',', 0, 17831) ;

CALL ImportField(10114118, '', 'REGIONCLS', '', ' ', 1, 101, 4, 0, ',', 0, 17831) ;

--    (), (1)
CALL ImportField(20110009, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 201, 0, 0, ',', 0, 36865) ;

CALL ImportField(20110082, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 201, 0, 0, ',', 0, 17473) ;

CALL ImportField(20111057, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 201, 1, 0, ',', 0, 36853) ;

CALL ImportField(20111185, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEKey', 1, 201, 1, 1, ',', 0, 17425) ;

--  (), (1)
CALL ImportField(20210069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 202, 0, 0, ',', 0, 36865) ;

CALL ImportField(20210090, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 202, 0, 1, ',', 0, 17473) ;

CALL ImportField(20211072, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 202, 1, 0, ',', 0, 36853) ;

CALL ImportField(20211107, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 202, 1, 1, ',', 0, 17425) ;

--   (), (1)
CALL ImportField(20310069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 203, 0, 0, ',', 0, 17473) ;

CALL ImportField(20310081, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 203, 0, 1, ',', 0, 36865) ;

CALL ImportField(20311071, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 203, 1, 0, ',', 0, 36853) ;

CALL ImportField(20311097, ' .  ()', 'FINTYPE', '   ()', 'DestFINTYPEClsKey', 1, 203, 1, 1, ',', 0, 17425) ;

--  , , (1)
CALL ImportField(20410069, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 204, 0, 0, ',', 0, 17473) ;

CALL ImportField(20410086, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 204, 0, 1, ',', 0, 36865) ;

CALL ImportField(20411071, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 204, 1, 0, ',', 0, 17425) ;

CALL ImportField(20411116, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 204, 1, 1, ',', 0, 36853) ;

-- , (1)
CALL ImportField(20510067, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 205, 0, 0, ',', 0, 36865) ;

CALL ImportField(20510089, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 205, 0, 1, ',', 0, 17473) ;

CALL ImportField(20511069, ' . ', 'FINTYPECode', '  ', 'DestFINTYPE', 1, 205, 1, 0, ',', 0, 36853) ;

CALL ImportField(20511101, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEKey', 1, 205, 1, 1, ',', 0, 17425) ;

--    (), (1)
CALL ImportField(20610070, ' ', 'DocBaseCODE', ' ', 'DocBase', 1, 206, 0, 0, ',', 0, 36865) ;

CALL ImportField(20610089, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 206, 0, 1, ',', 0, 17473) ;

CALL ImportField(20611073, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 206, 1, 0, ',', 0, 36853) ;

CALL ImportField(20611185, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 206, 1, 1, ',', 0, 17425) ;

--   , (1)
CALL ImportField(20710070, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 207, 0, 0, ',', 0, 36865) ;

CALL ImportField(20710160, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 207, 0, 1, ',', 0, 17473) ;

CALL ImportField(20711073, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 207, 1, 0, ',', 0, 36853) ;

CALL ImportField(20711184, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 207, 1, 1, ',', 0, 17425) ;

--    , (1)
CALL ImportField(20810070, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 208, 0, 0, ',', 0, 36865) ;

CALL ImportField(20810160, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 208, 0, 1, ',', 0, 17473) ;

CALL ImportField(20811073, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 208, 1, 0, ',', 0, 36853) ;

CALL ImportField(20811183, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 208, 1, 1, ',', 0, 17425) ;

--  , (1)
CALL ImportField(20910007, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 209, 0, 0, ',', 0, 36865) ;

CALL ImportField(20910019, '', 'NUMBER', '', 'Number', 1, 209, 0, 0, '', 0, null) ;

CALL ImportField(20910027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 209, 0, 1, ',', 0, null) ;

CALL ImportField(20911010, ' . ', 'FINTYPECode', '  ', 'DestFinTypeCls', 1, 209, 1, 1, ',', 0, 36853) ;

CALL ImportField(20911023, '', 'NOTE', '', 'Note', 1, 209, 1, 1, '', 0, null) ;

CALL ImportField(20911137, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 209, 1, 1, ',', 0, 17425) ;

CALL ImportField(20912006, '()', 'DirectionCLSCode', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912007, ' ', 'FACIALACC_CLS', ' ', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912009, '', 'FACTCODE', '', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912010, ' . ', 'FINTYPECode', '  ', ' ', 1, 209, 2, 0, ',', 0, null) ;

CALL ImportField(20912014, '()', 'INN', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912015, '()', 'INN20', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912016, '()', 'KCSRCode', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912017, '()', 'KESR', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912018, '()', 'KFSR', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912019, '()', 'KVRCode', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912020, '()', 'KVSRCode', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912021, ' ', 'MeansType', ' ', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912022, '()', 'NAME', '()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912023, '', 'NOTE', '', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912024, '', 'OrgNameAndAcc', '', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912025, ' ', 'REGIONCLS', ' ', ' ', 1, 209, 2, 0, ',,', 0, null) ;

CALL ImportField(20912027, ' ', 'SUBKESR', ' ', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912031, '  ', 'TransfertClsCode', '  ', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912032, ' ', 'ClsType', ' ', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912035, '   ()', 'TransfertCls', '   ()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912036, '  ()', 'SubsidyCls', '  ()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912037, '', 'KCSR', ' ()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912038, '', 'KVR', ' ()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912039, '', 'KVSR', ' ()', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912040, ' ', 'SubsidyClsCode', ' ', ' ', 1, 209, 2, 0, '', 0, null) ;

CALL ImportField(20912041, ' ()', 'FACT', '()', ' ', 1, 209, 2, 1, '', 0, null) ;

CALL ImportField(20912042, ' ()', 'DirectionCLS', '()', ' ', 1, 209, 2, 1, '', 0, null) ;

CALL ImportField(20912043, ' .  ()', 'FINTYPE', '  ', ' ', 1, 209, 2, 1, ',', 0, null) ;

--  , (1)
CALL ImportField(21010005, ' ', 'ClsType', ' ', ' ', 1, 210, 0, 0, '', 0, 24698) ;

CALL ImportField(21010010, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 210, 0, 1, ',', 0, 36865) ;

CALL ImportField(21010027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 210, 0, 1, ',', 0, 17473) ;

CALL ImportField(21011009, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 210, 1, 0, ',', 0, 36853) ;

CALL ImportField(21011046, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 210, 1, 1, ',', 0, 17425) ;

CALL ImportField(21012010, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 210, 2, 0, ',', 0, 36853) ;

CALL ImportField(21012060, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 210, 2, 1, ',', 0, 17425) ;

--  , (1)
CALL ImportField(21110017, '', 'NUMBER', '', 'Number', 1, 211, 0, 0, '', 0, null) ;

CALL ImportField(21110025, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 211, 0, 0, ',', 0, null) ;

CALL ImportField(21110027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 211, 0, 1, ',', 0, null) ;

CALL ImportField(21111009, ' ', 'FACIALACC_CLS', ' ', 'DestFacialAccCls', 1, 211, 1, 1, '', 0, null) ;

CALL ImportField(21111012, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 211, 1, 1, ',', 0, 36853) ;

CALL ImportField(21111019, '()', 'KESR', '()', 'DestKesr', 1, 211, 1, 1, '', 0, null) ;

CALL ImportField(21111020, '()', 'KFSR', '()', 'DestKfsr', 1, 211, 1, 1, '', 0, null) ;

CALL ImportField(21111023, ' ', 'MeansType', ' ', 'DestMeansTypeCls', 1, 211, 1, 1, '', 0, null) ;

CALL ImportField(21111025, '', 'NOTE', '', 'Note', 1, 211, 1, 1, '', 0, null) ;

CALL ImportField(21111029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 211, 1, 1, '', 0, null) ;

CALL ImportField(21111041, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 211, 1, 1, ',', 0, 17425) ;

CALL ImportField(21112002, '  ', 'TransfertClsCode', '  ', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112003, ' ', 'ClsType', ' ', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112005, '()', 'DirectionCLSCODE', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112006, ' ', 'FACIALACC_CLS', ' ', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112008, '', 'FACTCODE', '', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112009, ' . ', 'FINTYPECODE', '  ', ' ', 1, 211, 2, 0, ',', 0, null) ;

CALL ImportField(21112013, '()', 'INN', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112014, '()', 'INN20', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112015, '()', 'KCSRCode', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112016, '()', 'KESR', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112017, '()', 'KFSR', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112018, '()', 'KVRCode', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112019, '()', 'KVSRCode', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112020, ' ', 'MeansType', ' ', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112021, '()', 'NAME', '()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112022, '', 'NOTE', '', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112023, '', 'OrgNameAndAcc', '', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112024, ' ', 'REGIONCLS', ' ', ' ', 1, 211, 2, 0, ',,', 0, null) ;

CALL ImportField(21112026, ' ', 'SUBKESR', ' ', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112028, '   ()', 'TransfertCls', '   ()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112029, '  ()', 'SubsidyCls', '  ()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112030, '', 'KVR', ' ()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112031, '', 'KVSR', ' ()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112032, '', 'KCSR', ' ()', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112033, ' ', 'SubsidyClsCode', ' ', ' ', 1, 211, 2, 0, '', 0, null) ;

CALL ImportField(21112034, ' ()', 'FACT', '()', ' ', 1, 211, 2, 1, '', 0, null) ;

CALL ImportField(21112035, ' ()', 'DirectionCLS', '()', ' ', 1, 211, 2, 1, '', 0, null) ;

CALL ImportField(21112036, ' .  ()', 'FINTYPE', '  ', ' ', 1, 211, 2, 1, ',', 0, null) ;

--   , , (1)
CALL ImportField(21210017, '', 'NUMBER', '', 'Number', 1, 212, 0, 0, '', 0, null) ;

CALL ImportField(21210025, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 212, 0, 0, ',', 0, null) ;

CALL ImportField(21210027, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 212, 0, 1, ',', 0, null) ;

CALL ImportField(21211009, ' ', 'FACIALACC_CLS', ' ', 'DestFacialAccCls', 1, 212, 1, 1, '', 0, null) ;

CALL ImportField(21211012, ' . ', 'FINTYPECODE', '  ', 'DestFinTypeCls', 1, 212, 1, 1, ',', 0, 36853) ;

CALL ImportField(21211019, '()', 'KESR', '()', 'DestKesr', 1, 212, 1, 1, '', 0, null) ;

CALL ImportField(21211020, '()', 'KFSR', '()', 'DestKfsr', 1, 212, 1, 1, '', 0, null) ;

CALL ImportField(21211023, ' ', 'MeansType', ' ', 'DestMeansTypeCls', 1, 212, 1, 1, '', 0, null) ;

CALL ImportField(21211025, '', 'NOTE', '', 'Note', 1, 212, 1, 1, '', 0, null) ;

CALL ImportField(21211029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 212, 1, 1, '', 0, null) ;

CALL ImportField(21211041, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 212, 1, 1, ',', 0, 17425) ;

CALL ImportField(21212002, '  ', 'TransfertClsCode', '  ', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212003, ' ', 'ClsType', ' ', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212005, '()', 'DirectionCLSCODE', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212006, ' ', 'FACIALACC_CLS', ' ', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212008, '', 'FACTCODE', '', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212009, ' . ', 'FINTYPECODE', '  ', ' ', 1, 212, 2, 0, ',', 0, null) ;

CALL ImportField(21212013, '()', 'INN', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212014, '()', 'INN20', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212015, '()', 'KCSRCode', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212016, '()', 'KESR', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212017, '()', 'KFSR', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212018, '()', 'KVRCode', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212019, '()', 'KVSRCode', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212020, ' ', 'MeansType', ' ', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212021, '()', 'NAME', '()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212022, '', 'NOTE', '', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212023, '', 'OrgNameAndAcc', '', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212024, ' ', 'REGIONCLS', ' ', ' ', 1, 212, 2, 0, ',,', 0, null) ;

CALL ImportField(21212026, ' ', 'SUBKESR', ' ', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212028, '   ()', 'TransfertCls', '   ()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212029, '  ()', 'SubsidyCls', '  ()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212030, '', 'KVR', ' ()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212031, '', 'KVSR', ' ()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212032, '', 'KCSR', ' ()', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212033, ' ', 'SubsidyClsCode', ' ', ' ', 1, 212, 2, 0, '', 0, null) ;

CALL ImportField(21212034, ' ()', 'FACT', '()', ' ', 1, 212, 2, 1, '', 0, null) ;

CALL ImportField(21212035, ' ()', 'DirectionCLS', '()', ' ', 1, 212, 2, 1, '', 0, null) ;

CALL ImportField(21212036, ' .  ()', 'FINTYPE', '  ', ' ', 1, 212, 2, 1, ',', 0, null) ;

CALL ImportField(21212037, ' ()', 'Org_Ref', ' ()', ' ', 1, 212, 2, 1, '', 0, null) ;

--  , (1)
CALL ImportField(30111012, ' .  .', 'SourceFinTypeCode', '   ', 'SourceFINTYPECLS', 1, 301, 1, 0, ',,', 0, 36853) ;

CALL ImportField(30111024, ' .  -', 'DestFinTypeCode', '   ', 'DestFINTYPECLS', 1, 301, 1, 0, 'DestFinType,,', 0, 36853) ;

CALL ImportField(30111031, ' ', 'SourceDocBaseCode', ' ', 'SOURCEDOCBASE', 1, 301, 1, 0, ',,', 0, 36865) ;

CALL ImportField(30111032, ' ', 'DestDocBaseCode', ' ', 'DESTDOCBASE', 1, 301, 1, 0, 'DestDocBase,,', 0, 36865) ;

CALL ImportField(30111166, ' .  . ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 301, 1, 1, ',,', 0, 18893) ;

CALL ImportField(30111167, ' .  - ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 301, 1, 1, 'DestFinTypeKey,,', 0, 18902) ;

CALL ImportField(30111168, '  ()', 'SourceDocBase', ' ', 'SOURCEDOCBASEKey', 1, 301, 1, 1, ',,', 0, 18915) ;

CALL ImportField(30111169, '  ()', 'DestDocBase', ' ', 'DESTDOCBASEKey', 1, 301, 1, 1, 'DestDocBaseKey,,', 0, 18916) ;

--   \, (1)
CALL ImportField(30210135, '   ', 'StimateID', '   ', 'StimateID', 1, 302, 0, 0, '', 0, 18999) ;

CALL ImportField(30211011, ' . ', 'SOURCEFINTYPECODE', '  ', 'SOURCEFINTYPECLS', 1, 302, 1, 0, ',', 0, 36853) ;

CALL ImportField(30211016, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 302, 1, 0, ',', 0, 36865) ;

CALL ImportField(30211153, ' .  ()', 'SOURCEFINTYPE', '  ', 'SourceFINTYPECLSKey', 1, 302, 1, 1, ',', 0, 18893) ;

CALL ImportField(30211154, ' ()', 'SourceDocBase', '', 'SOURCEDOCBASEKey', 1, 302, 1, 1, ',', 0, 18915) ;

--  (), (1)
CALL ImportField(30311024, ' . ', 'DestFinTypeCode', '  ', 'DestFinTypeCLS', 1, 303, 1, 0, ',', 0, 36853) ;

CALL ImportField(30311039, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 303, 1, 0, ',', 0, 36865) ;

CALL ImportField(30311092, ' .  - ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 303, 1, 1, ',', 0, 18902) ;

CALL ImportField(30311093, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 303, 1, 1, ',', 0, 18916) ;

--   , (1)
CALL ImportField(30411008, ' . ', 'SOURCEFINTYPECODE', '  ', 'SOURCEFINTYPECLS', 1, 304, 1, 0, ',', 0, 36853) ;

CALL ImportField(30411018, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 304, 1, 0, ',', 0, 36865) ;

CALL ImportField(30411143, ' .  ()', 'SOURCEFINTYPE', '  ', 'SourceFINTYPECLSKey', 1, 304, 1, 1, ',', 0, 18893) ;

CALL ImportField(30411144, ' ()', 'SourceDocBase', '', 'SOURCEDOCBASEKey', 1, 304, 1, 1, ',', 0, 18915) ;

--   \, (1)
CALL ImportField(30511022, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 305, 1, 0, ',', 0, 36853) ;

CALL ImportField(30511103, '', 'DestDocBaseCode', '', 'DestDocBase', 1, 305, 1, 0, ',', 0, 36865) ;

CALL ImportField(30511144, ' .  - ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 305, 1, 1, ',', 0, 18902) ;

CALL ImportField(30511145, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 305, 1, 1, ',', 0, 18916) ;

--   , (1)
CALL ImportField(30611032, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 306, 1, 0, ',', 0, 36853) ;

CALL ImportField(30611049, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 306, 1, 0, ',', 0, 36865) ;

CALL ImportField(30611146, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 306, 1, 1, ',', 0, 18902) ;

CALL ImportField(30611147, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 306, 1, 1, ',', 0, 18916) ;

--  , (1)
CALL ImportField(30811009, ' ', 'DestDocBaseCode', ' ', 'DESTDOCBASE', 1, 308, 1, 0, ',', 0, 36865) ;

CALL ImportField(30811018, ' .  ( )', 'DestFinTypeCode', '   -', 'DestFINTYPECLS', 1, 308, 1, 0, ',', 0, 36853) ;

CALL ImportField(30811030, '', 'NOTE', ' ', 'NOTE', 1, 308, 1, 0, '', 0, 18876) ;

CALL ImportField(30811036, ' ', 'SourceDocBaseCode', ' ', 'SOURCEDOCBASE', 1, 308, 1, 0, ',,', 0, 36865) ;

CALL ImportField(30811043, ' .  .', 'SourceFinTypeCode', '   .', 'SourceFINTYPECLS', 1, 308, 1, 0, ',,', 0, 36853) ;

CALL ImportField(30811107, ' .  . ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 308, 1, 1, ',,', 0, 18893) ;

CALL ImportField(30811108, ' .  ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 308, 1, 1, ',', 0, 18902) ;

CALL ImportField(30811109, '  ()', 'SourceDocBase', ' ', 'SOURCEDOCBASEKey', 1, 308, 1, 1, ',,', 0, 18915) ;

CALL ImportField(30811110, '  ()', 'DestDocBase', ' ', 'DESTDOCBASEKey', 1, 308, 1, 1, ',', 0, 18916) ;

--    , (1)
CALL ImportField(31111013, ' . ', 'SourceFinTypeCode', '  ', 'SourceFinTypeCls', 1, 311, 1, 0, ',', 0, 36853) ;

CALL ImportField(31111026, ' .  ', 'DestFinTypeCode', '   ', 'DestFinTypeCls', 1, 311, 1, 1, ',', 0, 36853) ;

CALL ImportField(31111042, '', 'SourceDocBaseCode', '', 'SOURCEDOCBASE', 1, 311, 1, 0, ',', 0, 36865) ;

CALL ImportField(31111104, ' .  ()', 'SourceFinType', '   ', 'SourceFINTYPECLSKey', 1, 311, 1, 1, ',', 0, 18893) ;

CALL ImportField(31111105, ' .   ()', 'DestFinType', '   ', 'DestFINTYPECLSKey', 1, 311, 1, 1, ',', 0, 18902) ;

CALL ImportField(31111106, ' ()', 'SourceDocBase', '', 'SOURCEDOCBASEKey', 1, 311, 1, 1, ',,', 0, 18915) ;

--     , (1)
CALL ImportField(31211025, ' . ', 'DestFINTYPECode', '  ', 'DestFINTYPECLS', 1, 312, 1, 0, ',', 0, 36853) ;

CALL ImportField(31211076, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 312, 1, 0, ',', 0, 36865) ;

CALL ImportField(31211140, ' ()', 'DestDocBase', '', 'DESTDOCBASEKEY', 1, 312, 1, 1, ',', 0, 18916) ;

CALL ImportField(31211141, ' . ', 'DestFINTYPE', '  ', 'DestFINTYPECLSKey', 1, 312, 1, 1, ',', 0, 18902) ;

--    , (1)
CALL ImportField(31411043, ' . ', 'SourceFINTYPECode', '   ', 'SourceFINTYPECLS', 1, 314, 1, 0, ',', 0, 36853) ;

CALL ImportField(31411076, '', 'SourceDocBaseCode', '', 'SourceDocBase', 1, 314, 1, 0, ',', 0, 36865) ;

CALL ImportField(31411139, ' .  ()', 'SourceFINTYPE', '   ', 'SourceFINTYPECLSKey', 1, 314, 1, 1, ',', 0, 18893) ;

CALL ImportField(31411140, ' ()', 'SourceDocBase', '', 'SourceDocBaseKey', 1, 314, 1, 1, ',', 0, 18915) ;

--      , (1)
CALL ImportField(31511045, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 315, 1, 0, ',', 0, 36853) ;

CALL ImportField(31511047, '', 'DestDocBaseCode', '', 'DestDocBase', 1, 315, 1, 0, ',', 0, 36865) ;

CALL ImportField(31511096, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 315, 1, 1, ',', 0, 18902) ;

CALL ImportField(31511097, ' ()', 'DestDocBase', '', 'DestDocBaseKey', 1, 315, 1, 1, ',', 0, 18916) ;

--   , (1)
CALL ImportField(32211042, ' . ', 'SourceFinTypeCode', '  ', ' ', 1, 322, 1, 0, ',', 0, 36853) ;

CALL ImportField(32211044, '', 'SourceDocBaseCode', '', ' ', 1, 322, 1, 0, ',', 0, 36865) ;

CALL ImportField(32211088, ' .  ()', 'SourceFinType', '  ', ' ', 1, 322, 1, 1, ',', 0, 18893) ;

CALL ImportField(32211089, ' ()', 'SourceDocBase', '', ' ', 1, 322, 1, 1, ',', 0, 18915) ;

--  , (1)
CALL ImportField(32311034, ' . ', 'DestFinTypeCode', '  ', 'DestFINTYPECLS', 1, 323, 1, 0, ',', 0, 36853) ;

CALL ImportField(32311036, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 323, 1, 0, ',,', 0, 36865) ;

CALL ImportField(32311155, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 323, 1, 1, ',', 0, 18902) ;

CALL ImportField(32311156, ' ()', 'DestDocBase', '', 'DESTDOCBASEKEY', 1, 323, 1, 1, ',,', 0, 18916) ;

--  , (1)
CALL ImportField(32411074, ' . ', 'DestFinTypeCode', '   -', 'DestFINTYPECLS', 1, 324, 1, 0, ',,', 0, 36853) ;

CALL ImportField(32411082, '', 'DestDocBaseCode', '', 'DESTDOCBASE', 1, 324, 1, 0, ',,', 0, 36865) ;

CALL ImportField(32411196, ' .  ()', 'DestFinType', '  ', 'DestFINTYPECLSKey', 1, 324, 1, 1, ',,', 0, 18902) ;

CALL ImportField(32411197, ' ()', 'DestDocBase', '', 'DESTDOCBASEKey', 1, 324, 1, 1, ',,', 0, 18916) ;

--    , (1)
CALL ImportField(40110034, '  ()', 'DocBaseCode', '  ', ' ', 1, 401, 0, 0, ',', 0, 36865) ;

CALL ImportField(40116250, '  ()', 'FINTYPE', ' ', ' ', 1, 401, 6, 1, ',', 0, 17833) ;

CALL ImportField(40110255, '  ()', 'FINTYPE', ' ', ' ', 1, 401, 10, 1, ',', 0, 17833) ;

--   , (1)
CALL ImportField(70111022, '', 'REGIONCLS', '', ' ', 1, 701, 1, 0, ',', 0, 17831) ;

--  , (1)
CALL ImportField(80111009, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 801, 1, 0, ',', 0, 36865) ;

CALL ImportField(80111017, ' . ', 'FINTYPECODE', ' . ', 'FinTypeCLS', 1, 801, 1, 0, '', 0, 36853) ;

CALL ImportField(80111082, ' .  ()', 'FINTYPE', '   ()', 'FinTypeCLSKey', 1, 801, 1, 1, '', 0, 18634) ;

CALL ImportField(80111083, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 801, 1, 1, ',', 0, 18664) ;

--   , (1)
CALL ImportField(90311049, '', 'DocBaseCode', '', 'DocBase', 1, 903, 1, 0, ',', 0, 36865) ;

CALL ImportField(90311087, ' .  ()', 'FinType', '  ', 'FINTYPEKey', 1, 903, 1, 1, ',', 0, 36856) ;

CALL ImportField(90311088, ' . ', 'FinTypeCode', '  ', 'FINTYPE', 1, 903, 1, 0, ',', 0, 36853) ;

CALL ImportField(90311091, ' ()', 'DocBase', '', 'DocBaseKey', 1, 903, 1, 1, ',', 0, 17709) ;

--   , (1)
CALL ImportField(90510027, '', 'DocBaseCode', '', ' ', 1, 905, 0, 0, ',', 0, 36865) ;

CALL ImportField(90510043, ' ()', 'DocBase', '', ' ', 1, 905, 0, 1, ',', 0, 17709) ;

-- , (1)
CALL ImportField(170110011, ' ()', 'DOCUMENTBASETYPE', ' ()', 'DOCUMENTBASETYPEKey', 1, 1701, 0, 0, ',', 0, 19157) ;

CALL ImportField(170110041, '', 'REGIONCLS', '', 'REGIONCLS', 1, 1701, 0, 0, ',', 0, 19142) ;

CALL ImportField(170110096, '', 'DocumentBaseTypeCode', '', 'DOCUMENTBASETYPE', 1, 1701, 0, 0, ',', 0, 36865) ;

-- (), (1)
CALL ImportField(170210038, '', 'RegionCls', '', ' ', 1, 1702, 0, 0, ',', 0, 19142) ;

--   , (1)
CALL ImportField(181610003, '', 'KVSR', ' ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610004, '', 'KFSR', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610005, '', 'KCSR', ' ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610006, '', 'KVR', ' ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610007, '', 'KESR', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610008, ' ', 'ID', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610009, ' /', 'PayDocNum', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610010, ' ', 'ElNum', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610011, ' ', 'NotUsedSumma', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610012, ' ', 'DestName', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610013, ' ', 'DestOrgRef', '  ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610014, ' ', 'DFAccount', '  ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610015, '  ', 'SourceAccRef', '  ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610016, ' ', 'SourceOrgRef', '  ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610017, ' ', 'InPayerOrgRef', '  ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610018, '   ', 'InPayerAccRef', '  ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610019, ' ', 'Summa', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610020, ' ', 'ProcDocClass', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610021, ' ', 'RegionCls', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610022, ' .  ()', 'FinType', '   ()', ' ', 1, 1816, 0, 0, ',', 0, null) ;

CALL ImportField(181610023, ' . ', 'FinTypeCode', '  ', ' ', 1, 1816, 0, 0, ',', 0, null) ;

CALL ImportField(181610024, ' ', 'FacialAccMaster', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610025, ' ', 'TypeOperationCls', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610026, '', 'KVRCode', ' ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610027, '', 'KVSRCode', ' ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610028, '', 'KCSRCode', ' ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610029, ' ()', 'DirectionCls', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610030, '', 'DirectionClsCode', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610031, ' ()', 'Fact', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610032, '', 'FactCode', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610033, ' ', 'MeansType', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610034, ' ', 'SubKESR', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610035, ' ', 'FinSource', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610036, ' ', 'KD', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610037, '', 'IFS', '  ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610038, '', 'BuhOperationCls', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610039, '', 'BudgetRef', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610040, ' ()', 'DocBase', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610041, '', 'DocBaseCode', '', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610042, '  ()', 'BuhPaymentsCls', '. ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610043, '   ()', 'TransfertCls', '   ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610044, '  ', 'TransfertClsCode', '  ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610045, '  ()', 'SubsidyCls', '  ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610046, ' ', 'SubsidyClsCode', ' ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610047, '   ()', 'BudAllocationCls', '   ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610048, '  ', 'BudAllocationClsCode', '  ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610049, '   ()', 'PayPromiseCls', '   ()', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610050, '  ', 'PayPromiseClsCode', '  ', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610051, '', 'DocType', ' (.  )', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181610098, ' ', 'ClsType', '  (, , )', ' ', 1, 1816, 0, 0, '', 0, null) ;

CALL ImportField(181611052, ' ', 'ID', 'ID', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611053, ' /', 'PayDocNum', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611054, ' ', 'ElNum', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611055, ' ', 'DFAccount', '  ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611056, ' ', 'InPayerOrgRef', '  ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611057, '   ', 'InPayerAccRef', '  ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611058, ' ', 'Summa', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611059, ' ', 'RegionCls', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611060, '', 'DocType', ' (.  )', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611061, ' ', 'MeansType', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611062, ' ', 'TypeOperationCls', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611063, '', 'KFSR', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611064, '', 'KVSR', ' ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611065, '', 'KVSRCode', ' ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611066, '', 'KCSR', ' ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611067, '', 'KCSRCode', ' ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611068, '', 'KVR', ' ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611069, '', 'KVRCode', ' ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611070, '', 'KESR', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611071, ' ()', 'DirectionCls', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611072, '', 'DirectionClsCode', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611073, ' ', 'SubKESR', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611074, ' ', 'FinSource', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611075, ' ()', 'Fact', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611076, '', 'FactCode', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611077, ' .  ()', 'FinType', '   ()', ' ', 1, 1816, 1, 0, ',', 0, null) ;

CALL ImportField(181611078, ' . ', 'FinTypeCode', '  ', ' ', 1, 1816, 1, 0, ',', 0, null) ;

CALL ImportField(181611079, ' ', 'KD', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611080, ' ', 'FullKDValue', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611081, '', 'IFS', '  ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611082, '', 'FullFinSourceValue', '  ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611083, '', 'BudgetRef', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611084, ' ()', 'DocBase', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611085, '', 'DocBaseCode', '', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611086, '   ()', 'TransfertCls', '   ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611087, '  ', 'TransfertClsCode', '  ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611088, '  ()', 'SubsidyCls', '  ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611089, ' ', 'SubsidyClsCode', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611090, '   ()', 'BudAllocationCls', '   ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611091, '  ', 'BudAllocationClsCode', '  ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611092, '   ()', 'PayPromiseCls', '   ()', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611093, '  ', 'PayPromiseClsCode', '  ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611094, '  ()', 'BuhPaymentCls', '. ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611095, ' ', 'FacialAccMaster', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611096, ' ', 'ProcDocClass', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

CALL ImportField(181611097, '', 'BuhOperationCls', ' ', ' ', 1, 1816, 1, 0, '', 0, null) ;

--  (), (1)
CALL ImportField(190110012, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1901, 0, 0, ',', 0, 36865) ;

CALL ImportField(190110087, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1901, 0, 1, ',', 0, 17473) ;

CALL ImportField(190111024, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1901, 1, 0, ',', 0, 36853) ;

CALL ImportField(190111104, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1901, 1, 1, ',', 0, 17425) ;

--    (), (1)
CALL ImportField(190210073, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1902, 0, 0, ',', 0, 36865) ;

CALL ImportField(190210086, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1902, 0, 1, ',', 0, 17473) ;

CALL ImportField(190211077, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1902, 1, 0, ',', 0, 36853) ;

CALL ImportField(190211102, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1902, 1, 1, ',', 0, 17425) ;

--   (), (1)
CALL ImportField(190310072, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1903, 0, 0, ',', 0, 36865) ;

CALL ImportField(190310087, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1903, 0, 1, ',', 0, 17473) ;

CALL ImportField(190311075, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1903, 1, 0, ',', 0, 36853) ;

CALL ImportField(190311103, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1903, 1, 1, ',', 0, 17425) ;

--    (), (1)
CALL ImportField(190610073, ' ', 'DocBaseCode', ' ', 'DocBase', 1, 1906, 0, 0, ',', 0, 17473) ;

CALL ImportField(190610088, '  ()', 'DocBase', '  ()', 'DocBaseKey', 1, 1906, 0, 1, ',', 0, 17473) ;

CALL ImportField(190611076, ' . ', 'FINTYPECODE', '  ', 'DestFINTYPECls', 1, 1906, 1, 0, ',', 0, 36853) ;

CALL ImportField(190611105, ' .  ()', 'FINTYPE', '  ', 'DestFINTYPEClsKey', 1, 1906, 1, 1, ',', 0, 17425) ;

--   (), (1)
CALL ImportField(220110009, ' ', 'DOCBASECODE', ' ', 'DocBase', 1, 2201, 0, 0, ',', 0, 36865) ;

CALL ImportField(220110070, '  ()', 'DOCBASE', '  ()', 'DocBaseKey', 1, 2201, 0, 1, ',', 0, 17473) ;

CALL ImportField(220111018, ' ', 'REGIONCLS', '', 'RegionCLS', 1, 2201, 1, 0, ',', 0, 17417) ;

CALL ImportField(220111074, ' .  ()', 'FinType', '  ', 'DestFINTYPEKey', 1, 2201, 1, 1, ',', 0, 17425) ;

CALL ImportField(220111075, ' . ', 'FinTypeCode', '  ', 'DestFINTYPECls', 1, 2201, 1, 0, ',', 0, 36853) ;

--  , +(2)
CALL ImportField(250410046, '/c ', 'FacialAcc_Cls', '', 'FacialAcc_Cls', 2, 2504, 0, 0, '', 0, 19803) ;

-- -, +(2)
CALL ImportField(300611049, ' . ', 'FinTypeCode', '', ' ', 2, 3006, 1, 0, '', 0, 36853) ;

CALL ImportField(300611054, ' .  ()', 'FinType', '', ' ', 2, 3006, 1, 1, '', 0, 21114) ;

--   , (1)
CALL ImportField(361010006, ' ', 'RegionCLS', ' ', '', 1, 3610, 0, 0, ',', 0, null) ;

--  , +(2)
CALL ImportField(480110031, ' ()', 'DocBase', '', 'DocBaseKey', 2, 4801, 0, 0, ',', 0, 31675) ;

CALL ImportField(480110033, '', 'DocBaseCode', '', 'DocBase', 2, 4801, 0, 0, ',', 0, null) ;

--    , (1)
CALL ImportField(550111071, ' . ', 'FinTypeCode', '  ', 'FinType', 1, 5501, 1, 0, ',', 0, 36853) ;

CALL ImportField(550111164, ' .  ()', 'FinType', '  ', 'FinTypeKey', 1, 5501, 1, 1, ',', 0, 22925) ;

--    , (1)
CALL ImportField(550211071, ' . ', 'FinTypeCode', '  ', 'FinType', 1, 5502, 1, 0, ',', 0, 36853) ;

CALL ImportField(550211144, ' .  ()', 'FinType', '  ', 'FinTypeKey', 1, 5502, 1, 1, ',', 0, 22925) ;

--    , (1)
CALL ImportField(550311060, ' .  ()', 'FinType', '  ', 'FinTypeKey', 1, 5503, 1, 1, ',', 0, 31724) ;

--  , (1)
CALL ImportField(991610029, ' \ ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null) ;

CALL InsertConst(-1, 3, 3, ' \ ', '', 0, 0, null) ;

CALL ImportField(991610030, ' \ ', '_', '', ' ', 1, 9916, 0, 1, '', 0, null) ;

CALL InsertConst(-1, 5, 3, ' \ ', '', 0, 0, null) ;

CALL ImportField(991610217, ' \ \    ', '_', '', ' ', 1, 9916, 0, 0, '', 0, null) ;

CALL InsertConst(-1, 31, 3, ' \ \    ', '', 0, 0, 9916) ;

--  , (1)
CALL ImportField(991710006, '  ', '', '', ' ', 1, 9917, 0, 1, '', 0, null) ;

CALL InsertConst(30, 35, 3, '  ', '', 0, 0, null) ;

CALL ImportField(991710025, ' . ', '', '', ' ', 1, 9917, 0, 0, '', 0, null) ;

CALL InsertConst(30, 10, 8, ' . ', '', 0, 0, 9917) ;


--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_DELETE('      ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     , ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('   ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     , ',1816, 0, 1) ;

CALL DOCLOCK_DELETE('     ,  ',1816, 0, 1) ;

--  "   ()"
CALL DOCLOCKFIELDS_INSERTFIELD('     ,  ',1816,0,181610043,1) ;

CALL DOCLOCK_IMPORT('    ',32768,9903,0,0,3,0,'((53,1,3)=1)  ("200", (53,3,8))',1,3,'        ',2,'',null,'',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 9903, 0, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310085,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310076,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310020,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310010,1) ;

--  " "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310004,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310003,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310002,1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310001,1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310062,1) ;

--  "   "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9903,0,990310061,1) ;

CALL DOCLOCK_IMPORT('    ',0,9912,0,0,11,0,'',0,1,' \ - \  \      .   \     ',0,'    - /         /    .',null,'((([984110031]=("..",.[991210001]))
    ([984110031]=("/.",.[991210014])))
 (([984110003]=0)([984110003]=.[991210001]))
 ((((.[991210017]<>0)(.[991210019]<>0))([984110041]<>0))
   (([984110042]<>0)
   ((.[991210006]<>0)(.[991210007]<>0)(.[991210008]<>0)))
  ))
([984110021]=0)',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 9912, 0, 0, 1) ;

--  "/ "
CALL DOCLOCKFIELDS_INSERTFIELD('    ',9912,0,991210018,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
		 (id<>ID_)	
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_IMPORT(520300600,' - ',null,520100,30800,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520300700,' - ',null,520101,30801,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(30303900,'->',null,30800,30200,'',1,0,0,0,1,'',1,'','',0,'',0,0) ;

CALL LINKTYPE_IMPORT(20204600,'->_',null,20300,20200,'   ()   ()',1,0,0,1,1,'',1,'','1616',0,'',1,0) ;

CALL LINKTYPE_IMPORT(30304000,'->',null,30800,30500,'',1,0,0,0,1,'',1,'','',0,'',0,0) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_IMPORT(980357600,'.DESTFACIALACC_CLS()->.ID',984110021,30810064,0,0) ;

CALL STATICLINK_IMPORT(995200600,'.1.TRANSFERTCLS()->.ID',988410002,520111052,0,0) ;

CALL STATICLINK_IMPORT(981800100,'.MEANSTYPE()->.ID',984910002,181610033,0,0) ;

CALL STATICLINK_IMPORT(991800000,'.TRANSFERTCLS()->.ID',988410002,181610043,0,0) ;

CALL STATICLINK_IMPORT(991800100,'.SUBSIDYCLS()->.ID',988910006,181610045,0,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (925, 101000, 102000, TO_DATE('15.09.2015 8:37:48', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.03, 30.06, 36.10, 37.01, 39.01, 42.01, 42.02, 42.03, 44.01, 44.03, 48.01, 49.01, 49.02, 49.03, 50.00, 52.01, 53.01, 53.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29', 'SHISHKOV/shishkov', TO_DATE('15.09.2015 9:12:4', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('10.20.00', 1020, 00, ' 10.2')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
